import time

from datetime import datetime
from calendar import monthrange
from netforce.model import Model, fields, get_model

from . import utils

class ReportHDCaseSummary(Model):
    _name="clinic.report.hd.case.summary"
    _string="Hemodialysis Report Summary"
    _transient=True
    
    _fields={
        "date": fields.Date("Month", required=True),
    }

    _defaults={
        'date': lambda *a: time.strftime("%Y-%m-%d"),        
    }
    
    def get_report_data(self,ids,context={}):
        for item in get_model("company").search_browse([]):
            company_name=item.name

        date=datetime.now().strftime("%Y-%m-%d")
        if ids:
            obj=self.browse(ids)[0]
            date=obj.date 
        crr_month=int(date[5:7])
        prev_month=crr_month-1
        next_month=crr_month+1
        if crr_month==1:
            prev_month=12
        if crr_month==12:
            next_month=1

        year=int(date[0:4])
        month_str=utils.MONTHS['th_TH'][crr_month]
        next_month_str=utils.MONTHS['th_TH'][next_month]
        prev_month_str=utils.MONTHS['th_TH'][prev_month]
              
        dom=[]
        weekday, prev_total_day=monthrange(year, prev_month)
        prev_time_start='2014-%s-01 00:00:00'%(str(prev_month).zfill(2))
        prev_time_stop='2014-%s-%s 23:59:59'%(str(prev_month).zfill(2),prev_total_day)
        dom.append(['time_start','>=', prev_time_start])
        dom.append(['time_stop','<=',prev_time_stop])
        prev_total=len(get_model("clinic.hd.case").search(dom))

        dom=[]
        weekday, crr_total_day=monthrange(year, crr_month)
        crr_time_start='2014-%s-01 00:00:00'%(str(crr_month).zfill(2))
        crr_time_stop='2014-%s-%s 23:59:59'%(str(crr_month).zfill(2),crr_total_day)
        dom.append(['time_start','>=', crr_time_start])
        dom.append(['time_stop','<=',crr_time_stop])
        crr_total=len(get_model("clinic.hd.case").search(dom))

        dom=[]
        weekday, next_total_day=monthrange(year, next_month)
        next_time_start='2014-%s-01 00:00:00'%(str(next_month).zfill(2))
        next_time_stop='2014-%s-%s 23:59:59'%(str(next_month).zfill(2),next_total_day)
        dom.append(['time_start','>=', next_time_start])
        dom.append(['time_stop','<=',next_time_stop])
        next_total=len(get_model("clinic.hd.case").search(dom))

        items={
            'topic1': {
                'month': month_str,
                'amount': crr_total,
                'date_from': crr_time_start[0:10],
                'date_to': crr_time_stop[0:10],
            },
            'topic2':
            {
                'month': prev_month_str,
                'amount': prev_total,
                'date_from': prev_time_start[0:10],
                'date_to': prev_time_stop[0:10],
            },
            'topic3':
            {
                'month': month_str,
                'amount': next_total,
                'date_from': next_time_start[0:10],
                'date_to': next_time_stop[0:10],
            },
            'topic4':
            {
                'month': month_str,
                'amount': 'N/A',
                'date_from': '',
                'date_to': '',
            },
            'topic5':
            {
                'month': next_month_str,
                'amount': 'N/A',
                'date_from': '',
                'date_to': '',
            },
            'topic6':
            {   
                'month': '',
                'amount': '',
                'date_from': '',
                'date_to': '',
            },
            'topic7':
            {
                'month':'',
                'amount': '',
                'date_from': '',
                'date_to': '',
            },
            'topic8':
            {
                'month': '',
                'amount': '',
                'date_from': '',
                'date_to': '',
            },
        }

        lines=[] 
        index=1
        for item in items:
            topic='topic%s'%index
            name=utils.TOPICS[topic]['name']
            unit=utils.TOPICS[topic]['unit']
            line=items[topic]
            line['topic']=name
            line['unit']=unit
            lines.append(line)
            index+=1

        new_pt_lines=[]
        for i in range(3):
            new_pt_lines.append({
                'no': i+1,
                'name': 'xxxxx',
                'note': '',
            })

        resign_pt_lines=[]
        for i in range(5):
            resign_pt_lines.append({
                'no': i+1,
                'name': 'xxxxx',
                'note': '',
            })

        data={
            'month': month_str,
            'year': year,
            'lines': lines,
            'new_pt_lines': new_pt_lines,
            'resign_pt_lines': resign_pt_lines,
            'company_name': company_name,
        }
        return data

ReportHDCaseSummary.register()
